@@ -209,10 +209,12 @@ class AristaL3SyncWorker(worker.BaseWorker):
         for server in self._servers:
             eos_svis = self.get_svis(server)
             eos_vlans = self.get_vlans(server)
-            svis_to_delete = (eos_svis - self._protected_vlans
-                              - expected_vlans)
-            vlans_to_delete = (eos_vlans - self._protected_vlans
-                               - expected_vlans)
+            svis_to_delete = (
+                eos_svis - self._protected_vlans - expected_vlans
+            )
+            vlans_to_delete = (
+                eos_vlans - self._protected_vlans - expected_vlans
+            )
             delete_cmds = []
             delete_cmds.extend('no interface vlan %s' % svi
                                for svi in svis_to_delete)
