@@ -168,8 +168,8 @@ class MechTestBase(test_plugin.Ml2PluginV2TestCase):
                 trunk_rpc = self.trunk_plugin._rpc_backend._skeleton
                 trunk_rpc.update_trunk_status(
                     self.context, port['trunk_details']['trunk_id'], 'ACTIVE')
-        elif (port.get(portbindings.VNIC_TYPE) == 'normal'
-              and vif_type == 'unbound'):
+        elif (port.get(portbindings.VNIC_TYPE) == 'normal' and
+              vif_type == 'unbound'):
             device_dict = {'agent_id': agent_id,
                            'device': port['id'],
                            'host': port.get(portbindings.HOST_ID)}
